==> jabber-muc_0.6.0.orig.tar.gz: jabber-muc-0.6.0.orig/include/ns.h <==
/*
 * MU-Conference - Multi-User Conference Service
 * Copyright (c) 2002 David Sutton
 *
 *
 * This program is free software; you can redistribute it and/or drvify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA02111-1307USA
 */

/* Namespace Defines for Conference namespaces */
#ifndef NS_MUC
#define NS_MUC			"http://jabber.org/protocol/muc"
#define NS_MUC_ADMIN 		"http://jabber.org/protocol/muc#admin"
#define NS_MUC_OWNER		"http://jabber.org/protocol/muc#owner"
#define NS_MUC_USER		"http://jabber.org/protocol/muc#user"
#endif

#ifndef NS_DISCO
#define NS_DISCO		"http://jabber.org/protocol/disco"
#define NS_DISCO_INFO		"http://jabber.org/protocol/disco#info"
#define NS_DISCO_ITEMS		"http://jabber.org/protocol/disco#items"
#endif

#ifndef NS_GROUPCHAT
#define NS_GROUPCHAT		"gc-1.0"
#endif

#ifndef NS_NEGOTIATE
#define NS_NEGOTIATE		"jabber:iq:negotiate"
#endif

#ifndef NS_X_CONFERENCE    
#define NS_X_CONFERENCE		"jabber:x:conference"
#endif

/* Status code defines */
#ifndef NS_DATA    
#define NS_DATA			"jabber:x:data"
#endif

==> jabber-muc_0.8.orig.tar.gz: jabber-muc-0.8/include/ns.h <==
/*
 * MU-Conference - Multi-User Conference Service
 * Copyright (c) 2002-2005 David Sutton
 *
 *
 * This program is free software; you can redistribute it and/or drvify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA02111-1307USA
 */

/* Namespace Defines for Conference namespaces */
#ifndef NS_MUC
#define NS_MUC			"http://jabber.org/protocol/muc"
#define NS_MUC_ADMIN 		"http://jabber.org/protocol/muc#admin"
#define NS_MUC_OWNER		"http://jabber.org/protocol/muc#owner"
#define NS_MUC_USER		"http://jabber.org/protocol/muc#user"
#define NS_MUC_ROOMINFO		"http://jabber.org/protocol/muc#roominfo"
#define NS_MUC_UNIQUE		"http://jabber.org/protocol/muc#unique"
#define NS_MUC_ROOMCONFIG "http://jabber.org/protocol/muc#roomconfig"
#endif

#ifndef NS_PING
#define NS_PING			"urn:xmpp:ping"
#endif

#ifndef NS_DISCO
#define NS_DISCO		"http://jabber.org/protocol/disco"
#define NS_DISCO_INFO		"http://jabber.org/protocol/disco#info"
#define NS_DISCO_ITEMS		"http://jabber.org/protocol/disco#items"
#endif

#ifndef NS_GROUPCHAT
#define NS_GROUPCHAT		"gc-1.0"
#endif

#ifndef NS_NEGOTIATE
#define NS_NEGOTIATE		"jabber:iq:negotiate"
#endif

#ifndef NS_X_CONFERENCE    
#define NS_X_CONFERENCE		"jabber:x:conference"
#endif

/* Status code defines */
#ifndef NS_DATA    
#define NS_DATA			"jabber:x:data"
#endif
